@@ -294,8 +294,8 @@ public:
                 extract_dimensions(v.m_type)
                 dims = convert_dims(n_dims, m_dims, size);
                 sub = format_type(dims, "std::string", v.m_name, use_ref, dummy);
-            } else if (ASR::is_a<ASR::Struct_t>(*v.m_type)) {
-                ASR::Struct_t *t = ASR::down_cast<ASR::Struct_t>(v_m_type);
+            } else if (ASR::is_a<ASR::StructType_t>(*v.m_type)) {
+                ASR::StructType_t *t = ASR::down_cast<ASR::StructType_t>(v_m_type);
                 std::string der_type_name = ASRUtils::symbol_name(t->m_derived_type);
                 std::string encoded_type_name = "x" + der_type_name;
                 std::string type_name = std::string("struct ") + der_type_name;
@@ -537,10 +537,9 @@ Kokkos::View<T*> from_std_vector(const std::vector<T> &v)
         std::string indent(indentation_level * indentation_spaces, ' ');
         from_std_vector_helper = indent + "Kokkos::View<float*> r;\n";
         std::string out = "from_std_vector<float>({";
-        for (size_t i=0; i<x.n_args; i++) {
-            this->visit_expr(*x.m_args[i]);
-            out += src;
-            if (i < x.n_args-1) out += ", ";
+        for (size_t i=0; i<(size_t) ASRUtils::get_fixed_size_of_array(x.m_type); i++) {
+            out += ASRUtils::fetch_ArrayConstant_value(x, i);
+            if (i < (size_t) ASRUtils::get_fixed_size_of_array(x.m_type)-1) out += ", ";
         }
         out += "})";
         from_std_vector_helper += indent + "r = " + out + ";\n";
@@ -701,10 +700,8 @@ Result<std::string> asr_to_cpp(Allocator &al, ASR::TranslationUnit_t &asr,
     diag::Diagnostics &diagnostics, CompilerOptions &co,
     int64_t default_lower_bound)
 {
-    LCompilers::PassOptions pass_options;
-    pass_options.always_run = true;
-    pass_options.fast = co.fast;
-    pass_unused_functions(al, asr, pass_options);
+    co.po.always_run = true;
+    pass_unused_functions(al, asr, co.po);
     ASRToCPPVisitor v(diagnostics, co, default_lower_bound);
     try {
         v.visit_asr((ASR::asr_t &)asr);
