@@ -1248,6 +1248,7 @@ public:
         out = "call ";
         switch ( x.m_intrinsic_id ) {
             SET_INTRINSIC_SUBROUTINE_NAME(RandomNumber, "random_number");
+            SET_INTRINSIC_SUBROUTINE_NAME(RandomInit, "random_init");
             default : {
                 throw LCompilersException("IntrinsicImpureSubroutine: `"
                     + ASRUtils::get_intrinsic_name(x.m_intrinsic_id)
@@ -1355,6 +1356,7 @@ public:
     }
 
     void visit_IntegerConstant(const ASR::IntegerConstant_t &x) {
+        // TODO: handle IntegerBOZ
         src = std::to_string(x.m_n);
         int kind = ASRUtils::extract_kind_from_ttype_t(x.m_type);
         if (kind != 4) {
@@ -1365,8 +1367,6 @@ public:
         last_expr_precedence = Precedence::Ext;
     }
 
-    // void visit_IntegerBOZ(const ASR::IntegerBOZ_t &x) {}
-
     // void visit_IntegerBitNot(const ASR::IntegerBitNot_t &x) {}
 
     void visit_IntegerUnaryMinus(const ASR::IntegerUnaryMinus_t &x) {
