@@ -247,7 +247,8 @@ intrinsic_funcs_args = {
     "Sign": [
         {
             "args": [("int", "int"), ("real", "real")],
-            "ret_type_arg_idx": 0
+            "ret_type_arg_idx": 0,
+            "same_kind_arg": 2
         },
     ],
     "Radix": [
@@ -256,6 +257,13 @@ intrinsic_funcs_args = {
             "return": "int32"
         },
     ],
+    "StorageSize": [
+        {
+            "args": [("any",)],
+            "return": "int32",
+            "kind_arg": True
+        },
+    ],
     "Nearest": [
         {
             "args": [("real", "real")],
@@ -720,7 +728,7 @@ intrinsic_funcs_args = {
     ], 
     "Ishftc": [
         {
-            "args": [("int", "int")],
+            "args": [("int", "int", "int")],
             "ret_type_arg_idx": 0
         },
     ],
@@ -807,6 +815,7 @@ skip_create_func = ["Partition"]
 compile_time_only_fn = [
     "Epsilon",
     "Radix",
+    "StorageSize",
     "Range",
     "Precision",
     "Rank",
@@ -993,7 +1002,7 @@ def add_create_func_return_src(func_name):
             src += indent * 2 + "ASR::ttype_t* type = ASRUtils::expr_type(args[0]);\n"
             src += indent * 2 + "if (ASR::is_a<ASR::Array_t>(*type)) {\n"
             src += indent * 3 + "ASR::Array_t* e = ASR::down_cast<ASR::Array_t>(type);\n"
-            src += indent * 3 + f"return_type = TYPE(ASR::make_Array_t(al, type->base.loc, {ret_type_val}, e->m_dims, e->n_dims, ASR::array_physical_typeType::FixedSizeArray));\n"
+            src += indent * 3 + f"return_type = TYPE(ASR::make_Array_t(al, type->base.loc,  return_type, e->m_dims, e->n_dims, ASR::array_physical_typeType::FixedSizeArray));\n"
             src += indent * 2 + "}\n"
         src += indent * 2 + "if (all_args_evaluated(m_args)) {\n"
         src += indent * 3 +     f"Vec<ASR::expr_t*> args_values; args_values.reserve(al, {no_of_args});\n"
