@@ -64,6 +64,7 @@ inline std::string get_intrinsic_name(int64_t x) {
         INTRINSIC_NAME_CASE(Isnan)
         INTRINSIC_NAME_CASE(Nearest)
         INTRINSIC_NAME_CASE(CompilerVersion)
+        INTRINSIC_NAME_CASE(CommandArgumentCount)
         INTRINSIC_NAME_CASE(Spacing)
         INTRINSIC_NAME_CASE(Modulo)
         INTRINSIC_NAME_CASE(BesselJ0)
@@ -110,6 +111,7 @@ inline std::string get_intrinsic_name(int64_t x) {
         INTRINSIC_NAME_CASE(SubstrIndex)
         INTRINSIC_NAME_CASE(Range)
         INTRINSIC_NAME_CASE(Radix)
+        INTRINSIC_NAME_CASE(StorageSize)
         INTRINSIC_NAME_CASE(Hypot)
         INTRINSIC_NAME_CASE(SelectedIntKind)
         INTRINSIC_NAME_CASE(SelectedRealKind)
@@ -283,6 +285,8 @@ namespace IntrinsicElementalFunctionRegistry {
             {&Nearest::instantiate_Nearest, &Nearest::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::CompilerVersion),
             {nullptr, &CompilerVersion::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::CommandArgumentCount),
+            {nullptr, &CommandArgumentCount::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Spacing),
             {&Spacing::instantiate_Spacing, &Spacing::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Modulo),
@@ -415,6 +419,8 @@ namespace IntrinsicElementalFunctionRegistry {
             {&Sign::instantiate_Sign, &Sign::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Radix),
             {nullptr, &Radix::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::StorageSize),
+            {nullptr, &StorageSize::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Scale),
             {&Scale::instantiate_Scale, &Scale::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Dprod),
@@ -598,6 +604,8 @@ namespace IntrinsicElementalFunctionRegistry {
             "nearest"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::CompilerVersion),
             "compiler_version"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::CommandArgumentCount),
+            "command_argument_count"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Spacing),
             "spacing"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Modulo),
@@ -750,6 +758,8 @@ namespace IntrinsicElementalFunctionRegistry {
             "ishftc"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Radix),
             "radix"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::StorageSize),
+            "storage_size"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Scale),
             "scale"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Dprod),
@@ -971,6 +981,7 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"min", {&Min::create_Min, &Min::eval_Min}},
                 {"ishftc", {&Ishftc::create_Ishftc, &Ishftc::eval_Ishftc}},
                 {"radix", {&Radix::create_Radix, &Radix::eval_Radix}},
+                {"storage_size", {&StorageSize::create_StorageSize, &StorageSize::eval_StorageSize}},
                 {"scale", {&Scale::create_Scale, &Scale::eval_Scale}},
                 {"dprod", {&Dprod::create_Dprod, &Dprod::eval_Dprod}},
                 {"range", {&Range::create_Range, &Range::eval_Range}},
@@ -1031,7 +1042,7 @@ namespace IntrinsicElementalFunctionRegistry {
     }
 
     static inline create_intrinsic_function get_create_function(const std::string& name) {
-        return  std::get<0>(intrinsic_function_by_name_db.at(name));
+        return std::get<0>(intrinsic_function_by_name_db.at(name));
     }
 
     static inline verify_function get_verify_function(int64_t id) {
