@@ -16,6 +16,7 @@
 
 #include <libasr/pass/replace_do_loops.h>
 #include <libasr/pass/replace_for_all.h>
+#include <libasr/pass/while_else.h>
 #include <libasr/pass/replace_init_expr.h>
 #include <libasr/pass/replace_implied_do_loops.h>
 #include <libasr/pass/replace_array_op.h>
@@ -28,7 +29,7 @@
 #include <libasr/pass/replace_arr_slice.h>
 #include <libasr/pass/replace_flip_sign.h>
 #include <libasr/pass/replace_div_to_mul.h>
-// #include <libasr/pass/replace_symbolic.h>
+#include <libasr/pass/replace_symbolic.h>
 #include <libasr/pass/replace_intrinsic_function.h>
 #include <libasr/pass/replace_intrinsic_subroutine.h>
 #include <libasr/pass/replace_fma.h>
@@ -53,6 +54,7 @@
 #include <libasr/pass/replace_print_struct_type.h>
 #include <libasr/pass/promote_allocatable_to_nonallocatable.h>
 #include <libasr/pass/replace_function_call_in_declaration.h>
+#include <libasr/pass/replace_openmp.h>
 #include <libasr/codegen/asr_to_fortran.h>
 #include <libasr/asr_verify.h>
 #include <libasr/pickle.h>
@@ -76,10 +78,12 @@ namespace LCompilers {
         std::vector<std::string> _skip_passes, _c_skip_passes;
         std::map<std::string, pass_function> _passes_db = {
             {"do_loops", &pass_replace_do_loops},
+            {"while_else", &pass_while_else},
             {"global_stmts", &pass_wrap_global_stmts},
             {"implied_do_loops", &pass_replace_implied_do_loops},
             {"array_op", &pass_replace_array_op},
-            // {"symbolic", &pass_replace_symbolic},
+            {"symbolic", &pass_replace_symbolic},
+            {"flip_sign", &pass_replace_flip_sign},
             {"intrinsic_function", &pass_replace_intrinsic_function},
             {"intrinsic_subroutine", &pass_replace_intrinsic_subroutine},
             {"arr_slice", &pass_replace_arr_slice},
@@ -87,7 +91,6 @@ namespace LCompilers {
             {"print_list_tuple", &pass_replace_print_list_tuple},
             {"class_constructor", &pass_replace_class_constructor},
             {"unused_functions", &pass_unused_functions},
-            {"flip_sign", &pass_replace_flip_sign},
             {"div_to_mul", &pass_replace_div_to_mul},
             {"fma", &pass_replace_fma},
             {"sign_from_value", &pass_replace_sign_from_value},
@@ -106,6 +109,7 @@ namespace LCompilers {
             {"nested_vars", &pass_nested_vars},
             {"where", &pass_replace_where},
             {"function_call_in_declaration", &pass_replace_function_call_in_declaration},
+            {"openmp", &pass_replace_openmp},
             {"print_struct_type", &pass_replace_print_struct_type},
             {"unique_symbols", &pass_unique_symbols},
             {"insert_deallocate", &pass_insert_deallocate},
@@ -208,6 +212,7 @@ namespace LCompilers {
                 "global_stmts",
                 "transform_optional_argument_functions",
                 "init_expr",
+                "openmp",
                 "implied_do_loops",
                 "class_constructor",
                 "pass_list_expr",
@@ -215,7 +220,7 @@ namespace LCompilers {
                 "function_call_in_declaration",
                 "subroutine_from_function",
                 "array_op",
-                // "symbolic",
+                "symbolic",
                 "intrinsic_function",
                 "intrinsic_subroutine",
                 "subroutine_from_function",
@@ -228,6 +233,7 @@ namespace LCompilers {
                 "array_dim_intrinsics_update",
                 "do_loops",
                 "forall",
+                "while_else",
                 "select_case",
                 "inline_function_calls",
                 "unused_functions",
@@ -240,6 +246,7 @@ namespace LCompilers {
                 "global_stmts",
                 "transform_optional_argument_functions",
                 "init_expr",
+                "openmp",
                 "implied_do_loops",
                 "class_constructor",
                 "pass_list_expr",
@@ -247,7 +254,8 @@ namespace LCompilers {
                 "function_call_in_declaration",
                 "subroutine_from_function",
                 "array_op",
-                // "symbolic",
+                "symbolic",
+                "flip_sign",
                 "intrinsic_function",
                 "intrinsic_subroutine",
                 "subroutine_from_function",
@@ -261,10 +269,10 @@ namespace LCompilers {
                 "array_dim_intrinsics_update",
                 "do_loops",
                 "forall",
+                "while_else",
                 "dead_code_removal",
                 "select_case",
                 "unused_functions",
-                "flip_sign",
                 "sign_from_value",
                 "div_to_mul",
                 "fma",
